==> haskell-hint-0.9.0.8-82.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hint
version:              0.9.0.8
visibility:           public
id:                   hint-0.9.0.8-B8f5YwBPf4WLoDBZ7X3imp
key:                  hint-0.9.0.8-B8f5YwBPf4WLoDBZ7X3imp
license:              BSD-3-Clause
maintainer:           "Samuel Gélineau" <gelisam@gmail.com>
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             A Haskell interpreter built on top of the GHC API
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  d06f315497f4d1911314cdd809e924e1
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hint
hs-libraries:         HShint-0.9.0.8-B8f5YwBPf4WLoDBZ7X3imp
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl transformers-0.6.1.0
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hint-0.9.0.8-83-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hint
version:              0.9.0.8
visibility:           public
id:                   hint-0.9.0.8-9ZLqnKbXnXu19br7AITIs8
key:                  hint-0.9.0.8-9ZLqnKbXnXu19br7AITIs8
license:              BSD-3-Clause
maintainer:           "Samuel Gélineau" <gelisam@gmail.com>
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             A Haskell interpreter built on top of the GHC API
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  129347ebda1845378069c78faab5a94e
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hint-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hint
hs-libraries:         HShint-0.9.0.8-9ZLqnKbXnXu19br7AITIs8
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC transformers-0.6.1.0
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
